pub fn ru<'pokemon_ru>() -> Vec<&'pokemon_ru str> {
    vec![
        // GEN 1
        "Бульбазавр",
        "Ивизавр",
        "Венузавр",
        "Чармандер",
        "Чармелеон",
        "Чаризард",
        "Сквиртл",
        "Вартортл",
        "Бластойз",
        "Катерпи",
        "Метапод",
        "Баттерфри",
        "Видл",
        "Какуна",
        "Бидрилл",
        "Пиджи",
        "Пиджеотто",
        "Пиджит",
        "Раттата",
        "Рэтикейт",
        "Спироу",
        "Фироу",
        "Эканс",
        "Эрбок",
        "Пикачу",
        "Райчу",
        "Сэндшру",
        "Сэндслэш",
        "Нидоран♀",
        "Нидорина",
        "Нидоквин",
        "Нидоран♂",
        "Нидорино",
        "Нидокинг",
        "Клефейри",
        "Клефейбл",
        "Вульпикс",
        "Найнтейлс",
        "Джигглипуф",
        "Вигглитаф",
        "Зубат",
        "Голбат",
        "Оддиш",
        "Глум",
        "Вайлплум",
        "Парас",
        "Парасект",
        "Венонат",
        "Веномот",
        "Диглетт",
        "Дагтрио",
        "Мяут",
        "Персиан",
        "Псидак",
        "Голдак",
        "Манки",
        "Праймейп",
        "Гроулит",
        "Арканайн",
        "Поливаг",
        "Поливирл",
        "Поливрэт",
        "Абра",
        "Кадабра",
        "Алаказам",
        "Мачоп",
        "Мачок",
        "Мачемп",
        "Беллспраут",
        "Випинбелл",
        "Виктрибел",
        "Тентакул",
        "Тентакруэль",
        "Джеодуд",
        "Гравелер",
        "Голем",
        "Понита",
        "Рапидаш",
        "Слоупок",
        "Слоубро",
        "Магнемайт",
        "Магнетон",
        "Фарфетчд",
        "Додуо",
        "Додрио",
        "Сил",
        "Дьюгонг",
        "Граймер",
        "Мак",
        "Шеллдер",
        "Клойстер",
        "Гастли",
        "Хонтер",
        "Генгар",
        "Оникс",
        "Дроузи",
        "Гипно",
        "Крабби",
        "Кинглер",
        "Волторб",
        "Электрод",
        "Экзеггут",
        "Экзеггутор",
        "Кубон",
        "Маровак",
        "Хитмонли",
        "Хитмончан",
        "Ликитунг",
        "Коффинг",
        "Визинг",
        "Райхорн",
        "Райдон",
        "Ченси",
        "Тангела",
        "Кангасхан",
        "Хорси",
        "Сидра",
        "Голдин",
        "Сикинг",
        "Старью",
        "Старми",
        "Мистер Майм",
        "Скайтер",
        "Джинкс",
        "Электробазз",
        "Магмар",
        "Пинсир",
        "Торос",
        "Мэджикарп",
        "Гаярдос",
        "Лапрас",
        "Дитто",
        "Иви",
        "Вапореон",
        "Джолтеон",
        "Флареон",
        "Поригон",
        "Оманайт",
        "Омастар",
        "Кабуто",
        "Кабутопс",
        "Аэродактиль",
        "Снорлакс",
        "Артикуно",
        "Запдос",
        "Молтрес",
        "Дратини",
        "Драгонэйр",
        "Драгонит",
        "Мьюту",
        "Мью",
        // GEN 2
        "Чикорита",
        "Бейлиф",
        "Меганиум",
        "Синдаквил",
        "Квилава",
        "Тайфложн",
        "Тотодайл",
        "Кроконав",
        "Фералигатр",
        "Сентрет",
        "Фуррет",
        "Хутхут",
        "Ноктаул",
        "Ледиба",
        "Ледиан",
        "Спинарак",
        "Ариадос",
        "Кробат",
        "Чинчоу",
        "Лантурн",
        "Пичу",
        "Клеффа",
        "Игглибафф",
        "Тогепи",
        "Тогетик",
        "Нату",
        "Ксату",
        "Мэрип",
        "Флаффи",
        "Амфарос",
        "Беллоссом",
        "Мэрилл",
        "Азумэрилл",
        "Судовудо",
        "Политод",
        "Хоппип",
        "Скиплум",
        "Джамплафф",
        "Эйпом",
        "Санкерн",
        "Санфлора",
        "Янма",
        "Вупер",
        "Квэгсайр",
        "Эспеон",
        "Амбреон",
        "Маркроу",
        "Слоукинг",
        "Мисдривус",
        "Аноун",
        "Воббафет",
        "Жирафариг",
        "Пайнеко",
        "Форретресс",
        "Данспорс",
        "Глайгер",
        "Стиликс",
        "Снаббл",
        "Гранбулл",
        "Квилфиш",
        "Сизор",
        "Шакл",
        "Геракросс",
        "Снизел",
        "Теддиурса",
        "Урсаринг",
        "Слагма",
        "Магкарго",
        "Свайнаб",
        "Пилосвайн",
        "Корсола",
        "Реморейд",
        "Октиллери",
        "Дэлибёд",
        "Мантин",
        "Скармори",
        "Хаундаур",
        "Хаундум",
        "Кингдра",
        "Фанфи",
        "Донфан",
        "Поригон 2",
        "Стэнтлер",
        "Смиргл",
        "Тирогу",
        "Хитмонтоп",
        "Смучам",
        "Элекид",
        "Магби",
        "Милтанк",
        "Блисси",
        "Райкоу",
        "Энтей",
        "Суйкун",
        "Ларвитар",
        "Пупитар",
        "Тиранитар",
        "Люджия",
        "Хо-Ох",
        "Целеби",
        // GEN 3
        "Трико",
        "Гроувайл",
        "Скептайл",
        "Торчик",
        "Комбускен",
        "Блейзикен",
        "Мадкип",
        "Марштомп",
        "Свамперт",
        "Пучиена",
        "Майтиена",
        "Зигзагун",
        "Лайнун",
        "Вёрмпл",
        "Силкун",
        "Бьютифлай",
        "Каскун",
        "Дастокс",
        "Лотад",
        "Ломбре",
        "Лудиколо",
        "Сидот",
        "Назлиф",
        "Шифтри",
        "Тейлоу",
        "Свеллоу",
        "Вингалл",
        "Пелиппер",
        "Ральтс",
        "Кирлия",
        "Гардевуар",
        "Сёрскит",
        "Маскверейн",
        "Шрумиш",
        "Брелум",
        "Слэйкот",
        "Вигорот",
        "Слэйкинг",
        "Нинкада",
        "Нинджаск",
        "Шединджа",
        "Висмур",
        "Лаудред",
        "Эксплауд",
        "Макухита",
        "Харияма",
        "Азурилл",
        "Ноуспасс",
        "Скитти",
        "Делкатти",
        "Саблай",
        "Мэвайл",
        "Арон",
        "Лейрон",
        "Аггрон",
        "Медитайт",
        "Медичам",
        "Электрайк",
        "Манектрик",
        "Плюсл",
        "Минун",
        "Волбит",
        "Иллюмизи",
        "Розалия",
        "Галпин",
        "Свалот",
        "Карванна",
        "Шарпидо",
        "Вэйлмер",
        "Вэйлорд",
        "Намел",
        "Камерапт",
        "Торкл",
        "Споинк",
        "Грампиг",
        "Спинда",
        "Трапинч",
        "Вибрава",
        "Флайгон",
        "Какния",
        "Кактурн",
        "Сваблу",
        "Алтария",
        "Зангус",
        "Сивайпер",
        "Лунатон",
        "Солрок",
        "Барбоа",
        "Вискэш",
        "Корфиш",
        "Кродант",
        "Балтой",
        "Клэйдол",
        "Лилип",
        "Крэдили",
        "Анорит",
        "Армальдо",
        "Фибас",
        "Майлотик",
        "Кастформ",
        "Кеклеон",
        "Шаппет",
        "Бэнетт",
        "Даскулл",
        "Дасклопс",
        "Тропиус",
        "Чаймеко",
        "Эбсол",
        "Винаут",
        "Снорант",
        "Глэйли",
        "Сфил",
        "Силео",
        "Уолрейн",
        "Кламперл",
        "Хантэйл",
        "Горебисс",
        "Реликант",
        "Лювдиск",
        "Багон",
        "Шелгон",
        "Саламенс",
        "Белдум",
        "Метанг",
        "Метагросс",
        "Реджирок",
        "Реджайс",
        "Реджистил",
        "Латиас",
        "Латиос",
        "Кайогр",
        "Граудон",
        "Рэйкваза",
        "Джирачи",
        "Деоксис",
    ]
}
